==> org-lsst-ccs-subsystem-power-gui-1.5.4-sources.jar: org/lsst/ccs/subsystem/power/ui/jas/ATSPowerControlPlugin.java <==
package org.lsst.ccs.subsystem.power.ui.jas;

import javax.swing.JPanel;
import org.lsst.ccs.bus.data.KeyValueData;
import org.lsst.ccs.bus.messages.EmbeddedObjectDeserializationException;
import org.lsst.ccs.bus.messages.StatusMessage;
import org.lsst.ccs.bus.messages.StatusSubsystemData;
import org.lsst.ccs.gconsole.annotations.Plugin;
import org.lsst.ccs.gconsole.base.Console;
import org.lsst.ccs.gconsole.base.ConsolePlugin;
import org.lsst.ccs.gconsole.services.optpage.OptionalPage;
import org.lsst.ccs.messaging.StatusMessageListener;
import org.lsst.ccs.subsystem.power.constants.PowerAgentProperties;
import org.lsst.ccs.subsystem.power.data.ATSPowerState;
import org.lsst.ccs.subsystem.power.ui.ATSPowerControlPanel;

/**
 * @author tonyj
 */
@Plugin(name = "ATS Power Supply Plugin", description = "ATS Power Supply Plugin")
public class ATSPowerControlPlugin extends ConsolePlugin {

    @Override
    public void initialize() {
        OptionalPage optPage = new MonitorOptionalPage(PowerAgentProperties.ATS_POWER_AGENT, ATSPowerControl.class,
                                                       MonitorFilter.class, null);
        Console.getConsole().getOptionalPageService().add(optPage);
    }
    
    static class ATSPowerControl implements Control, StatusMessageListener {

        private CommandSender cmdSender;
        private ATSPowerControlPanel ctrlPanel;
        
        @Override
        public void onStatusMessage(StatusMessage msg) {
            try {
                StatusSubsystemData sd = (StatusSubsystemData)msg;
                if (sd.getDataKey().equals(ATSPowerState.KEY)) {
                    updateControlPanel(((KeyValueData)sd.getSubsystemData()).getValue());
                }
            }
            catch (EmbeddedObjectDeserializationException x) {
            }
        }

        @Override
        public JPanel getControlPanel(CommandSender sndr) {
            cmdSender = sndr;
            return ctrlPanel = new ATSPowerControlPanel(sndr);
        }

        @Override
        public void initControlPanel() {
            updateControlPanel(cmdSender.sendCommand(null, "getFullState"));
        }

        @Override
        public void updateControlPanel(Object obj) {
            ctrlPanel.updateControlPanel((ATSPowerState)obj);
        }

        @Override
        public void disableSystem() {
            ctrlPanel.disableSystem();
        }

        @Override
        public StatusMessageListener getListener() {
            return this;
        }
    }
    
}

==> org-lsst-ccs-subsystem-power-gui-1.6.0-sources.jar: org/lsst/ccs/subsystem/power/ui/jas/ATSPowerControlPlugin.java <==
package org.lsst.ccs.subsystem.power.ui.jas;

import javax.swing.JPanel;
import org.lsst.ccs.bus.data.KeyValueData;
import org.lsst.ccs.bus.messages.EmbeddedObjectDeserializationException;
import org.lsst.ccs.bus.messages.StatusMessage;
import org.lsst.ccs.bus.messages.StatusSubsystemData;
import org.lsst.ccs.gconsole.annotations.Plugin;
import org.lsst.ccs.gconsole.base.Console;
import org.lsst.ccs.gconsole.base.ConsolePlugin;
import org.lsst.ccs.gconsole.services.optpage.OptionalPage;
import org.lsst.ccs.messaging.StatusMessageListener;
import org.lsst.ccs.subsystem.common.ui.jas.CommandSender;
import org.lsst.ccs.subsystem.common.ui.jas.ControlPanel;
import org.lsst.ccs.subsystem.common.ui.jas.MonOptionalPage;
import org.lsst.ccs.subsystem.power.constants.PowerAgentProperties;
import org.lsst.ccs.subsystem.power.data.ATSPowerState;
import org.lsst.ccs.subsystem.power.ui.ATSPowerControlPanel;

/**
 * @author tonyj
 */
@Plugin(name = "ATS Power Supply Plugin", description = "ATS Power Supply Plugin")
public class ATSPowerControlPlugin extends ConsolePlugin {

    @Override
    public void initialize() {
        OptionalPage optPage = new MonOptionalPage(PowerAgentProperties.ATS_POWER_AGENT, ATSPowerControl.class, null, false);
        Console.getConsole().getOptionalPageService().add(optPage);
    }
    
    public static class ATSPowerControl extends ControlPanel implements StatusMessageListener {

        private CommandSender cmdSender;
        private ATSPowerControlPanel ctrlPanel;
        
        @Override
        public void onStatusMessage(StatusMessage msg) {
            try {
                StatusSubsystemData sd = (StatusSubsystemData)msg;
                if (sd.getDataKey().equals(ATSPowerState.KEY)) {
                    updateControlPanel(((KeyValueData)sd.getSubsystemData()).getValue());
                }
            }
            catch (EmbeddedObjectDeserializationException x) {
            }
        }

        @Override
        public JPanel getControlPanel(CommandSender sndr) {
            cmdSender = sndr;
            return ctrlPanel = new ATSPowerControlPanel(sndr);
        }

        @Override
        public void initControlPanel() {
            updateControlPanel(cmdSender.sendCommand(null, "getFullState"));
        }

        @Override
        public void updateControlPanel(Object obj) {
            ctrlPanel.updateControlPanel((ATSPowerState)obj);
        }

        @Override
        public void disableSystem() {
            ctrlPanel.disableSystem();
        }

        @Override
        public StatusMessageListener getListener() {
            return this;
        }
    }
    
}
